Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(639)

Unified Diff: sdk/lib/_internal/compiler/compiler.dart

Issue 12154006: Remove Sink and move CollectionSink to async. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Remove usage of Sink from pub. Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/http/lib/src/streamed_request.dart ('k') | sdk/lib/_internal/compiler/implementation/compiler.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sdk/lib/_internal/compiler/compiler.dart
diff --git a/sdk/lib/_internal/compiler/compiler.dart b/sdk/lib/_internal/compiler/compiler.dart
index cf7eb2acb14b523a2109aead124eb4a63e4df25b..bbee705a0386725a035cfbb0f97a335768543b70 100644
--- a/sdk/lib/_internal/compiler/compiler.dart
+++ b/sdk/lib/_internal/compiler/compiler.dart
@@ -22,7 +22,7 @@ typedef Future<String> CompilerInputProvider(Uri uri);
typedef Future<String> ReadStringFromUri(Uri uri);
/**
* Returns a [Sink] that will serve as compiler output for the given
* component.
*
* Components are identified by [name] and [extension]. By convention,
@@ -41,7 +41,8 @@ typedef Future<String> ReadStringFromUri(Uri uri);
* As more features are added to the compiler, new names and
* extensions may be introduced.
*/
-typedef Sink<String> CompilerOutputProvider(String name, String extension);
+typedef StreamSink<String> CompilerOutputProvider(String name,
+ String extension);
/**
* Invoked by the compiler to report diagnostics. If [uri] is
« no previous file with comments | « pkg/http/lib/src/streamed_request.dart ('k') | sdk/lib/_internal/compiler/implementation/compiler.dart » ('j') | no next file with comments »
@@ -22,7 +22,7 @@ typedef Future<String> CompilerInputProvider(Uri uri);
typedef Future<String> ReadStringFromUri(Uri uri);
/**
- * Returns a [Sink] that will serve as compiler output for the given
+ * Returns a [StreamSink] that will serve as compiler output for the given
* component.
*

Powered by Google App Engine
This is Rietveld 408576698